#
# spec file for package xsd
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xsd
Version:        4.1.0
Release:        3.2
Summary:        W3C XML schema to C++ data binding compiler
# http://www.codesynthesis.com/products/xsd/license.xhtml
License:        SUSE-GPL-2.0-with-FLOSS-exception
URL:            https://www.codesynthesis.com/products/xsd/
Source0:        https://codesynthesis.com/~boris/tmp/xsd/%{version}.a11/%{name}-%{version}.a11+dep.tar.bz2
Source1:        cxx-tree-guide.pdf
Source2:        cxx-parser-guide.pdf
Source3:        cxx-tree-manual.pdf
Source99:       xsd-rpmlintrc
# Rename xsd to xsdcxx
Patch0:         xsdcxx-rename.patch
# PATCH-FIX-UPSTREAM -- CVE-2024-50602
Patch1:         CVE-2024-50602.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  ghostscript
BuildRequires:  libboost_headers-devel
BuildRequires:  libxerces-c-devel > 2.8.0
BuildRequires:  m4
Requires:       libxerces-c-devel

%description
CodeSynthesis XSD is an open-source, cross-platform W3C XML Schema to
C++ data binding compiler. Provided with an XML instance specification
(XML Schema), it generates C++ classes that represent the given
vocabulary as well as parsing and serialization code.
You can then access the data stored in XML using types and functions
that semantically correspond to your application domain rather than
dealing with intricacies of reading and writing XML.

%package        doc
Summary:        API documentation files for xsd
Group:          Documentation/Other
Requires:       xsd
BuildArch:      noarch

%description    doc
This package contains API documentation for xsd.

%prep
%autosetup -p1 -n %{name}-%{version}.a11+dep

%build
%make_build CXXFLAGS="%{optflags}"

%install
make install_prefix="%{buildroot}%{_prefix}" install

# Rename xsd to xsdcxx to avoid conflicting with mono-web package.
mv %{buildroot}%{_bindir}/xsd %{buildroot}%{_bindir}/xsdcxx
mv %{buildroot}%{_datadir}/doc/xsd %{buildroot}%{_datadir}/doc/xsdcxx
mv %{buildroot}%{_mandir}/man1/xsd.1 %{buildroot}%{_mandir}/man1/xsdcxx.1

# Remove duplicate docs.
rm -r %{buildroot}%{_datadir}/doc/libxsd

# the pdf creation relies on a double conversion, first to create a ps file, then a PDF
# the process produces unreproducible builds. Replace with pre-generated files
cp -f %{SOURCE1} %{buildroot}%{_datadir}/doc/xsdcxx/cxx/tree/cxx-tree-guide.pdf
cp -f %{SOURCE2} %{buildroot}%{_datadir}/doc/xsdcxx/cxx/tree/guide/cxx-parser-guide.pdf
cp -f %{SOURCE3} %{buildroot}%{_datadir}/doc/xsdcxx/cxx/tree/manual/cxx-tree-manual.pdf

%fdupes -s %{buildroot}%{_datadir}/doc

%files
%license xsd/LICENSE
%doc README xsd/NEWS xsd/GPLv2 xsd/FLOSSE
%{_bindir}/xsdcxx
%{_includedir}/xsd/
%{_mandir}/man1/xsdcxx.1%{?ext_man}

%files doc
%doc %{_datadir}/doc/xsdcxx

%changelog
* Wed Oct 30 2024 Christophe Marin <christophe@krop.fr>
- Add patch (CVE-2024-50602, boo#1232580)
  * CVE-2024-50602.patch
* Mon Aug  7 2023 Christophe Marin <christophe@krop.fr>
- Use pre-generated pdf files to have reproducible builds.
* Wed Feb 10 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 4.1.0
  * Support for abstract XML Schema types. The corresponding C++
    classes now have _clone() declared pure virtual which
    prevents construction of their instances.
- Drop 0001-Fix-build-with-GCC10.patch. Merged upstream.
- Rebase xsdcxx-rename.patch
* Thu Dec  5 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add 0001-Fix-build-with-GCC10.patch (boo#1158369)
- Run spec-cleaner
* Thu Feb  2 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Wed Jul 23 2014 cgiboudeaux@gmx.com
- Update to 4.0.0
  * Drop support for Xerces-C++ <= 2.8.0.
  * Oracle/Berkeley DB XML support has been dropped.
  * New option, --std, specifies the C++ standard that the generated code
    should conform to. Valid values are c++98 (default) and c++11.
  * New option, --fat-type-file, triggers the placement of code corresponding
    to global elements into type files instead of schema files in the file-
    per-type mode. This option is primarily useful when trying to minimize
    the amount of object code that is linked to an executable by packaging
    compiled generated code into a static (archive) library.
  * New option, --generate-dep, triggers the generation of the make
    dependency files (.d) for the generated C++ files. Other options
    controlling dependency generation are: --generate-dep-only,
  - -dep-phony, --dep-target, --dep-suffix, and --dep-regex. For
    details on this functionality, refer to the XSD compiler command
    line manual (man pages).
  * New option, --suppress-assignment, suppresses the generation of copy
    assignment operators for complex types. If this option is specified,
    the copy assignment operators for such types are declared private and
    left unimplemented.
  * New option, --polymorphic-plate, allows the creation of multiple
    polymorphic map plates in the same application. For details, refer
    to the XSD compiler command line manual (man pages).
  See the NEWS file for the complete changelog
- Drop boost1.46-buildfix.patch (no longer needed)
* Wed May  9 2012 cgiboudeaux@gmx.com
- Change license to SUSE-GPL-2.0-with-FLOSS-exception
* Fri May  4 2012 cgiboudeaux@gmx.com
- Update to 3.3.0.1
- Spec cleanup
* Tue Jul 28 2009 kalev@smartlink.ee
- Updated to work with openSUSE
* Mon Jul 27 2009 rel-eng@lists.fedoraproject.org
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild
* Tue Jul  7 2009 Antti.Andreimann@mail.ee
- Removed redundant PostScript files from the doc package
* Mon Jul  6 2009 Antti.Andreimann@mail.ee
- Added ACE homepage to SPEC file comments
- Added verbose=1 to MAKEFLAGS so compiler flags could be
  verified from build logs.
* Sat Jul  4 2009 Antti.Andreimann@mail.ee
- Changed License tag to clarify which exceptions we are talking about
* Wed May 20 2009 Antti.Andreimann@mail.ee
- Initial RPM release.
